==> arcan-0.0.1.tar.gz: arcan-0.0.1/README.md <==
# Arcan

### AI web3 tooling platform for decentralized customization and enhancement of AI agents

Arcan is a web3 tooling platform designed to customize and enhance AI agents by leveraging blockchain technology. With Arcan, developers can securely tie AI personalization to user-owned blockchain profiles, ensuring privacy and control while delivering tailored AI interactions.

Check out the live demo at [arcanai.tech](https://arcanai.tech/).

## Features

- **Blockchain-Backed AI Personalization**: Integrate AI agents with blockchain to create a personalized experience that respects user ownership.
- **Web3 Tooling**: A suite of tools that enable seamless interaction between AI agents and blockchain assets.
- **Privacy-Centric Design**: Ensuring user data is encrypted and owned by the user, accessible only through user permission.
- **Developer-Friendly**: Straightforward APIs to enable developers to focus on building unique AI experiences.

<p align="center">
  <a href="https://arcanai.tech">
    <img src="public/logo_dark.png" height="200">
    <h3 align="center"></h3>
  </a>
</p>

<p align="center">Unleash AI potential with Arcan — your gateway to blockchain-powered, personalized AI experiences. Code smart, own smarter. Visit the live demo at <a href="https://arcanai.tech/">arcanai.tech</a>.</p>

<br/>

## Built With

- [Next.js](https://nextjs.org/) - The web framework used
- [Python](https://www.python.org/) - Backend programming language
- [Rust](https://www.rust-lang.org/) - Smart contract programming language

## Installation

### Prerequisites

- [Next.js](https://nextjs.org/)
- [Python](https://www.python.org/)
- [Rust](https://www.rust-lang.org/)
- Access to a blockchain test network (e.g., Ethereum's or Solana's Testnet)

### Quick Install

    python -m pip install arcan

### Build from Source

    git clone https://github.com/Broomva/arcan.git
    cd arcan &&  make build

### Manual Build

    conda create -n arcan python=3.10
    conda activate arcan
    pip install -r requirements.txt
    python setup.py install

## Building the Next.js App

To clone the repository and create the Next.js app, you can use the following commands:

    npx create-next-app arcan --example "https://github.com/Broomva/arcan"

Once you have cloned the repository and created the app, install the dependencies:

    yarn install

After that, you can run the development server:

    yarn dev
    # or
    make rerun

You can then view your application by opening [http://localhost:3000](http://localhost:3000) with your browser.

## Contributing

Please read [CONTRIBUTING.md](https://github.com/broomva/arcan/CONTRIBUTING.md) for details on our code of conduct, and the process for submitting pull requests to us.

## Versioning

We use [SemVer](http://semver.org/) for versioning with release-please. For the versions available, see the [tags on this repository](https://github.com/broomva/arcan/tags).

## Authors

- **Carlos D. Escobar-Valbuena** - [broomva](https://github.com/broomva)

See also the list of [contributors](https://github.com/broomva/arcan/contributors) who participated in this project.

## Get Involved

Interested in Arcan or looking to collaborate? Visit [broomva.tech](https://broomva.tech) for more information and to get in touch.

## License

This project is licensed under the Apache 2.0 License - see the [LICENSE.md](LICENSE.md) file for details.

## Subscription Model

Arcan operates on a freemium/subscription model. While the open-source code can be deployed in your own environment free of charge, subscription tiers for access to premium features such as enhanced support and additional tools. Visit our [Pricing Page](https://arcanapp.io/pricing) for more details.

## Live Demo & Deployment

Check out the live demo at [arcanapp.io](https://arcanapp.io/).

To deploy Arcan on your own, you can clone & deploy it with one click:

[![Deploy with Vercel](https://vercel.com/button)](https://vercel.com/new/clone?repository-url=https%3A%2F%2Fgithub.com%2FBroomva%2Farcan%2Ftree%2Fmain)

## Learn More

To learn more about the technologies we use, check out:

- [Next.js Documentation](https://nextjs.org/docs)
- [FastAPI Documentation](https://fastapi.tiangolo.com/)

<!-- ## Attribution

Arcan builds upon the hard work of others. Here are the original repositories we leveraged:

- [NextJS FastAPI Template](https://github.com/digitros/nextjs-fastapi)

 -->

==> arcan-0.1.0.tar.gz: arcan-0.1.0/README.md <==
# Arcan

### AI web3 tooling platform for decentralized customization and enhancement of AI agents

Arcan is a web3 tooling platform designed to customize and enhance AI agents by leveraging blockchain technology. With Arcan, developers can securely tie AI personalization to user-owned blockchain profiles, ensuring privacy and control while delivering tailored AI interactions.

Check out the live demo at [arcanai.tech](https://arcanai.tech/).

## Features

- **Blockchain-Backed AI Personalization**: Integrate AI agents with blockchain to create a personalized experience that respects user ownership.
- **Web3 Tooling**: A suite of tools that enable seamless interaction between AI agents and blockchain assets.
- **Privacy-Centric Design**: Ensuring user data is encrypted and owned by the user, accessible only through user permission.
- **Developer-Friendly**: Straightforward APIs to enable developers to focus on building unique AI experiences.

<p align="center">
  <a href="https://arcanai.tech">
    <img src="public/arcan_logo.svg" height="200">
    <h3 align="center"></h3>
  </a>
</p>

<p align="center">Unleash AI potential with Arcan — your gateway to blockchain-powered, personalized AI experiences. Code smart, own smarter. Visit the live demo at <a href="https://arcanai.tech/">arcanai.tech</a>.</p>

<br/>

## Built With

<!-- - [Next.js](https://nextjs.org/) - The web framework used -->
- [Python](https://www.python.org/) - Backend programming language
- [Rust](https://www.rust-lang.org/) - Smart contract programming language

## Installation

### Prerequisites

<!-- - [Next.js](https://nextjs.org/) -->
- [Python](https://www.python.org/)
- [Rust](https://www.rust-lang.org/)
- Access to a blockchain test network (e.g., Ethereum's or Solana's Testnet)

### Quick Install

    python -m pip install arcan

### Build from Source

    git clone https://github.com/Broomva/arcan.git
    cd arcan &&  make build

### Manual Build

    conda create -n arcan python=3.10
    conda activate arcan
    pip install -r requirements.txt
    python setup.py install
<!-- 
## Building the Next.js App

To clone the repository and create the Next.js app, you can use the following commands:

    npx create-next-app arcan --example "https://github.com/Broomva/arcan"

Once you have cloned the repository and created the app, install the dependencies:

    yarn install

After that, you can run the development server:

    yarn dev
    # or
    make rerun

You can then view your application by opening [http://localhost:3000](http://localhost:3000) with your browser. -->

## Contributing

Please read [CONTRIBUTING.md](https://github.com/broomva/arcan/CONTRIBUTING.md) for details on our code of conduct, and the process for submitting pull requests to us.

## Versioning

We use [SemVer](http://semver.org/) for versioning with release-please. For the versions available, see the [tags on this repository](https://github.com/broomva/arcan/tags).

## Authors

- **Carlos D. Escobar-Valbuena** - [broomva](https://github.com/broomva)

See also the list of [contributors](https://github.com/broomva/arcan/contributors) who participated in this project.

## Get Involved

Interested in Arcan or looking to collaborate? Visit [broomva.tech](https://broomva.tech) for more information and to get in touch.

## License

This project is licensed under the Apache 2.0 License - see the [LICENSE.md](LICENSE.md) file for details.
<!-- 
## Subscription Model

Arcan operates on a freemium/subscription model. While the open-source code can be deployed in your own environment free of charge, subscription tiers for access to premium features such as enhanced support and additional tools. Visit our [Pricing Page](https://arcanapp.io/pricing) for more details.

## Live Demo & Deployment

Check out the live demo at [arcanapp.io](https://arcanapp.io/).

To deploy Arcan on your own, you can clone & deploy it with one click:

[![Deploy with Vercel](https://vercel.com/button)](https://vercel.com/new/clone?repository-url=https%3A%2F%2Fgithub.com%2FBroomva%2Farcan%2Ftree%2Fmain)

## Learn More

To learn more about the technologies we use, check out:

- [Next.js Documentation](https://nextjs.org/docs)
- [FastAPI Documentation](https://fastapi.tiangolo.com/) -->

<!-- ## Attribution

Arcan builds upon the hard work of others. Here are the original repositories we leveraged:

- [NextJS FastAPI Template](https://github.com/digitros/nextjs-fastapi)

 -->
